@@ -7,6 +7,8 @@
 # @param x numeric vector at which to evaluate the variance.
 #
 # @return Numeric vector with the variances of the maximum likelihood curve.
+#
+#' @export
 curve_variance.drda <- function(object, x) {
   len <- length(x)
 
@@ -28,7 +30,7 @@ curve_variance.drda <- function(object, x) {
   variance <- rep(NA_real_, len)
 
   for (i in seq_len(len)) {
-    variance[i] <- as.numeric(tcrossprod(crossprod(G[i, ], V), G[i, ]))
+    variance[i] <- as.numeric(tcrossprod(crossprod(G[i, idx], V), G[i, idx]))
   }
 
   variance
