@@ -1132,8 +1132,8 @@ test_that("fit", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic6_new(x, y, w, c(0, 1, 1, 1, 1, 1), max_iter, NULL, NULL)
@@ -1147,8 +1147,8 @@ test_that("fit", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1201,8 +1201,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1220,8 +1220,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1239,8 +1239,8 @@ test_that("fit_constrained: inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1292,8 +1292,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1311,8 +1311,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1330,8 +1330,8 @@ test_that("fit_constrained: equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1383,8 +1383,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1402,8 +1402,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1421,8 +1421,8 @@ test_that("fit_constrained: equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1476,8 +1476,8 @@ test_that("fit (weighted)", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   object <- loglogistic6_new(
@@ -1493,8 +1493,8 @@ test_that("fit (weighted)", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1548,8 +1548,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1567,8 +1567,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1586,8 +1586,8 @@ test_that("fit_constrained (weighted): inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 6)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1640,8 +1640,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with same equalities
@@ -1659,8 +1659,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values with different equalities
@@ -1678,8 +1678,8 @@ test_that("fit_constrained (weighted): equalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
@@ -1732,8 +1732,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values within the boundaries
@@ -1751,8 +1751,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 
   # initial values outside the boundaries
@@ -1770,8 +1770,8 @@ test_that("fit_constrained (weighted): equalities and inequalities", {
   expect_equal(result$estimated, estimated)
   expect_equal(result$rss, rss_value)
   expect_equal(result$df.residual, object$n - 4)
-  expect_equal(result$fitted.values, fitted_values)
-  expect_equal(result$residuals, residuals, tolerance = 1.0e-7)
+  expect_equal(result$fitted.values, fitted_values, tolerance = 1.0e-6)
+  expect_equal(result$residuals, residuals, tolerance = 1.0e-6)
   expect_equal(result$weights, w)
 })
 
